@@ -1,4 +1,4 @@
-package LabmanSoapInternal;
+package LabmanSoap;
 use strict;
 use SOAP::Lite ( maptype => {} );
 use Data::Dumper;
@@ -9,11 +9,11 @@ VMWare::LabmanSoap - access Vmware Labmanager SOAP API
 
 =head1 VERSION
 
-Version 0.99
+Version 1.0
 
 =cut
 
-our $VERSION = '0.99';
+our $VERSION = '1.0';
 
 =head1 SYNOPSIS
 
